@@ -67,7 +67,7 @@ class SQSClient(Boto3Client):
         """
         msg_body = query
         self.send_message(
-            QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/rds-queries-queue",
+            QueueUrl="https://sqs.eu-west-3.amazonaws.com/749868801319/rds-queries-queue.fifo",
             MessageBody=msg_body
         )
         
\ No newline at end of file
